Learn R Programming

RidgeFusion (version 1.0-3)

SSRidgeFused: Semis Supervised Ridge Fusion Model Based Clustering

Description

Calculates parameters for model based clustering using ridge fusion estimation of precision matrix

Usage

SSRidgeFused(Z, Xu, lambda1, lambda2, Scale=FALSE, warm=NULL,tol=.001)

Arguments

Z
A list of length J that contains the labeled data for each class
Xu
The unlabeled data
lambda1
A vector with all possible Ridge tuning parameters
lambda2
A vector with all possible Ridge Fusion tuning parameters
Scale
If TRUE scale invariant method is used
warm
Default is NULL, if initialized with mixing distributions for each of the unlabeled data, will use in initialization of parameters
tol
tolerence for convergence criterion of the alphas

Value

An object of class SSRidgeFusion, basically a list including elements
Omega
a list where each element is the precision matrix estimate for the corresponding element of S
Ridge
lambda1
FusedRidge
lambda2
iter
The number of iterations until the EM algorithm converged
Alpha
Mixing coefficients for each of the unlabeled data points
Means
Class/Cluster Means
Pi
Probability Mass Function for the classes

Examples

Run this code
## Creating a toy example with 5 variables
library(mvtnorm)
set.seed(526)
p=5
    Sig1=matrix(0,p,p)
	for(j in 1:p){
		for(i in j:p){          
            Sig1[j,i]=.7^abs(i-j)
            Sig1[i,j]=Sig1[j,i]
            
		}
	}
    Sig2=diag(c(rep(2,p-5),rep(1,5)),p,p)
X1=rmvnorm(100,rep(2*log(p)/p,p),Sig1)
Y=rmvnorm(100,,Sig2)

## Creating a list of the data for each class
Z=list(X1,Y)

##Creating Unlabeled data set
Z1=rmvnorm(250,rep(2*log(p)/p,p),Sig1)
Z2=rmvnorm(250,,Sig2)
ZU=rbind(Z1,Z2)
## Running Semi-Supervised Ridge Fused Model based clustering 
Hi=SSRidgeFused(Z,ZU,1,1,Scale=TRUE,warm=NULL)
## Showing example of a warm.start
Hi2=SSRidgeFused(Z,ZU,1,1,Scale=TRUE,warm=Hi$Alphas)

Run the code above in your browser using DataLab